import pybullet as p
import time
import pybullet_data
import numpy as np

def create_obj(path, pose):
    visualShapeId = p.createVisualShape(shapeType=p.GEOM_MESH,
                                        fileName=path,
                                        rgbaColor=[1, 1, 1, 1],
                                        specularColor=[0.4, .4, 0],
                                        meshScale=[1,1,1])
    collisionShapeId = p.createCollisionShape(shapeType=p.GEOM_MESH,
                                              fileName=path,
                                              meshScale=[1,1,1])
    obj_id = p.createMultiBody(0.5, collisionShapeId, visualShapeId, pose[:3], pose[3:])
    return obj_id

def capture():
    fov, aspect, nearplane, farplane = 60, 1.6, 0.01, 100
    projection_matrix = p.computeProjectionMatrixFOV(fov, aspect, nearplane, farplane)
    p1 = 2#np.random.uniform(0.5, 1.7)
    p2 = 2#np.random.uniform(0.8, 2)  # np.random.uniform(-0.3, 3)
    p3 = 0.6#np.random.uniform(0.3, 1.7)
    c3 = 0.5#np.random.uniform(0.2, 1.3)  # np.random.uniform(1, 3)
    c2 = 1#np.random.uniform(1, 2)  # np.random.uniform(1, 5)
    view_matrix = p.computeViewMatrix([p1, p2, p3], [0, 0, 0], [0, 0, 1])
    light_pos = [3, 1.5, 4]
    _, _, color, depth, segm = p.getCameraImage(512, 512, view_matrix, projection_matrix, light_pos, shadow=1,
                                                flags=p.ER_SEGMENTATION_MASK_OBJECT_AND_LINKINDEX,
                                                renderer=p.ER_BULLET_HARDWARE_OPENGL)

physicsClient = p.connect(p.GUI)
p.setAdditionalSearchPath(pybullet_data.getDataPath())
p.setGravity(0,0,-10)
planeId = p.loadURDF("plane.urdf")
startPos = [0,0,0.5]
startOrientation = p.getQuaternionFromEuler([0,0,0])
boxId = p.loadURDF("r2d2.urdf",startPos, startOrientation)
obj_path = "obj0/model.obj"

for i in range(10):
    pose=[np.random.uniform(-2, 2),np.random.uniform(-2, 2),np.random.uniform(0.8, 2),0,0,0,1]
    create_obj(obj_path, pose)

while True:
    p.stepSimulation()
    capture()
    time.sleep(0.01)

